| Copyright | (c) 2015 Nicolas DI PRIMA <nicolas@di-prima.fr> |
|---|---|
| License | BSD-style |
| Safe Haskell | None |
| Language | Haskell2010 |
Time.Compat
Contents
Description
Basic time conversion compatibility.
This module aims to help conversion between types from time package and types
from the time-hourglass package.
An example of use (taken from file examplesExampleTime/Compat.hs):
import Data.Hourglass as H import Time.Compat as C import Data.Time as T transpose :: T.ZonedTime -> H.LocalTime H.DateTime transpose oldTime = H.localTime offsetTime (H.DateTime newDate timeofday) where T.ZonedTime (T.LocalTime day tod) (T.TimeZone tzmin _ _) = oldTime newDate :: H.Date newDate = C.dateFromMJDEpoch $ T.toModifiedJulianDay day timeofday :: H.TimeOfDay timeofday = C.diffTimeToTimeOfDay $ toRational $ T.timeOfDayToTime tod offsetTime = H.TimezoneOffset $ fromIntegral tzmin
Synopsis
- dateFromUnixEpoch :: Integer -> Date
- dateFromMJDEpoch :: Integer -> Date
- diffTimeToTimeOfDay :: Real t => t -> TimeOfDay
- dateFromPOSIXEpoch :: Integer -> Date
- dateFromTAIEpoch :: Integer -> Date
Documentation
Arguments
| :: Integer | Number of days since the start of the Unix epoch (1970-01-01 00:00:00 UTC). |
| -> Date |
Given an integer which represents the number of days since the start of the Unix epoch (1970-01-01 00:00:00 UTC), yield the corresponding date in the proleptic Gregorian calendar.
Given an integer which represents the number of days since the start of the Modified Julian Date (MJD) epoch (1858-11-17 00:00:00 UTC), yields the corresponding date in the proleptic Gregorian calendar.
This function allows a user to convert a Day
into Date.
import qualified Data.Time.Calendar as T timeDay :: T.Day dateFromMJDEpoch $ T.toModifiedJulianDay timeDay
Given a real number representing the number of seconds since the start of
the day, yield a TimeOfDay value.
Example with DiffTime type from package time:
import qualified Data.Time.Clock as T difftime :: T.DiffTime diffTimeToTimeOfDay difftime
Example with the TimeOfDay type from package time:
import qualified Data.Time.Clock as T timeofday :: T.TimeOfDay diffTimeToTimeOfDay $ T.timeOfDayToTime timeofday
Deprecated
Arguments
| :: Integer | Number of days since the start of the Unix epoch (1970-01-01 00:00:00 UTC). |
| -> Date |
Deprecated: Will be removed from future versions of this package. Use dateFromUnixEpoch
Same as dateFromUnixEpoch.
Deprecated: Will be removed from future versions of this package. Use dateFromMJDEpoch
Same as dateFromMJDEpoch.
The name of this function is a misnomer, as the International Atomic Time (TAI) epoch starts on 1958-01-01 00:00:00 UTC.